@@ -33,15 +33,12 @@ Created on Wed Jul 11 10:40:30 2012
 
 @author: Daniele Bigoni (dabi@imm.dtu.dk)
 
-@version: 0.1
-
 UncertaintyQuantificationToolbox is the collection of tools for Uncertainty Quantification.
 
 @copyright: 2012-2014 The Technical University of Denmark
 """
 
-__all__ = ["UncertaintyQuantification","sobol_lib","CutANOVA"]
-__version__ = "0.1.1"
+__all__ = ["RandomSampling","ModelReduction","gPC","sobol_lib","CutANOVA","mcmc"]
 
 __author__ = "Daniele Bigoni"
 __copyright__ = """Copyright 2012-2014, The Technical University of Denmark"""
